# Copyright 2011, Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Author: David Torres <api.davidtorres@gmail.com>

package TestClientUtils;

use strict;
use vars qw(@EXPORT_OK @ISA);

use Google::Ads::AdWords::Client;

use Exporter;
use File::Basename;
use File::Spec;

@ISA = qw(Exporter);
@EXPORT_OK = qw(get_test_client get_test_client_no_auth);

sub get_test_client() {
  my $client = get_test_client_no_auth();

  if ($client->_is_oauth_enabled() || $client->__get_auth_token() ne "") {
    Google::Ads::AdWords::Logging::enable_all_logging();
    return $client;
  }
}

sub get_test_client_no_auth() {
  my $properties_file =
      File::Spec->catdir(dirname($0), qw(testdata client.properties));

  my $client = Google::Ads::AdWords::Client->new({
    properties_file => $properties_file
  });

  return $client;
}

return 1;
